clear
capture log close
#delimit;
set more off;

log using /data/melissas/table1/table1, replace ;

/*=======================================*/
/* program: /data/melissas/ldvtbl1.do    */
/*		renamed /table1.do       */
/* by: MS				 */
/* date: 5 July 1999			 */
/*					 */
/* purpose: generate additional numbers for ldv tables */
/* (ie, in addition to those from read1.do) */
/*					 */
/* data in: pums80m                      */
/* data out: 				 */
/*=======================================*/

set mem 100m;

use /data/melissas/pums80m;

gen byte hours0=(hourswm<=0);
gen byte hours10=(hourswm>0 & hourswm<=10);
gen byte hours20=(hourswm>10 & hourswm<=20);
gen byte hours30=(hourswm>20 & hourswm<=30);
gen byte hours40=(hourswm>30 & hourswm<=40);
gen byte hours50=(hourswm>40 & hourswm<=50);

gen byte weeks0=(weeksm1<=0);
gen byte weeks10=(weeksm1>0 & weeksm1<=10);
gen byte weeks20=(weeksm1>10 & weeksm1<=20);
gen byte weeks30=(weeksm1>20 & weeksm1<=30);
gen byte weeks40=(weeksm1>30 & weeksm1<=40);
gen byte weeks50=(weeksm1>40 & weeksm1<=50);


/************************/
* LDV TABLE 1;
/************************/
	
* MEANS OF SAMPLE, 1980 PUMS;

summ workedm hourswm morekids multi2nd 
     hours0 hours10 hours20 hours30 hours40 hours50 
     weeks0 weeks10 weeks20 weeks30 weeks40 weeks50, detail;

* OLS USING MOREKIDS;

regress workedm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem, robust;

regress hourswm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem, robust;


* OLS USING MOREKIDS, w/ EDUCM;

regress workedm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem educm, robust;

regress hourswm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem educm, robust;

* REDUCED FORM;

regress morekids multi2nd agem1 agefstm boy1st boy2nd blackm hispm othracem, robust;
regress workedm  multi2nd agem1 agefstm boy1st boy2nd blackm hispm othracem, robust;
regress hourswm  multi2nd agem1 agefstm boy1st boy2nd blackm hispm othracem, robust;

* IV USING MULTI2ND ;

regress workedm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem
	(multi2nd agem1 agefstm boy1st boy2nd blackm hispm othracem), robust;

regress hourswm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem
	(multi2nd agem1 agefstm boy1st boy2nd blackm hispm othracem), robust;


* NOTE: EDUCM WAS NOT INCLUDED IN THE MODELS REPORTED IN ANGRIST & EVANS (1988);

/*=======================================*/
* PROBIT ;
/*=======================================*/

preserve;
  
probit workedm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem, robust;
gen ahat1 = _b[morekids];
  
gen b0 = _b[_cons];
gen b1 = _b[morekids];
gen b2 = _b[agem1];
gen b3 = _b[agefstm];
gen b4 = _b[boy1st];
gen b5 = _b[boy2nd];
gen b6 = _b[blackm];
gen b7 = _b[hispm]; 
gen b8 = _b[othracem];
  
* save /data/melissas/table1/probit, replace;

* scaling factor:  SUM {D*phi(X'b + aD)} /SUM(D);

*use /data/melissas/table1/probit;

*summ b0-b8;

gen xbad = b0 + b1*morekids +b2*agem1 + b3*agefstm + b4*boy1st + b5*boy2nd + 
  b6*blackm + b7*hispm + b8*othracem;

gen phi = normd(xbad);
gen dphi = morekids*phi;

summ dphi;

gen num = _result(18);

summ morekids;
gen den = _result(18);

summ num den;

gen effect = b1*num/den;
summ effect;

restore;


* PROBIT - MARGINAL EFFECTS;
dprobit workedm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem, robust;

* PROBIT - MARGINAL EFFECTS, w/ EDUCM;
dprobit workedm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem educm, robust;


/*=======================================*/
* 2PM  - Effect on the Treated  ;
* marginal effect is = a1*E[Y|Y>0,D=1] + a2*P[Y>0|D=1] ;
* where 1(Y>0) = X'B1 + A1*D +e1 ;
* and   Y|Y>0 = X'B2 + A2*D + e2 ;
/*=======================================*/

version 5.0;

reg workedm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem, robust;

gen a1 = _b[morekids];
gen var_a1 = (_se[morekids])^2;

reg hourswm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem if hourswm>0, robust;

gen a2 = _b[morekids];
gen var_a2 = (_se[morekids])^2;
quietly summarize hourswm if hourswm>0 & morekids==1;
scalar yi1_bar = _result(3);
quietly summarize workedm if morekids==1;
scalar pi1_hat = _result(3);
scalar marg_eff = a1*yi1_bar + a2*pi1_hat;
di yi1_bar;
di pi1_hat;
di  marg_eff;


* Standard Errors, assuming cov(c1,c2)=0 & mean known: 
* sqrt(yi1_bar^2*Var(c1) + pi1_hat^2*Var(c2));

scalar se_me_iv = sqrt((yi1_bar^2)*var_a1 + (pi1_hat^2)*var_a2);

di se_me_iv;


/*=======================================*/
* TOBIT - effect on treated ;
/*=======================================*/

version 6.0;

* Use intreg to get robust se's ;

tobit hourswm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem, ll(0);

* Marginal effect of tobit - cdf(b'x/sigma)*beta ;
* which equals pob(nonlimit)*beta ;
* STATA calculates this according to model, not data; 
* so they're identical! ;

predict phi, pr(0,.);
summ phi if morekids==1 ;
scalar define scale = _result(3);
di scale;
gen effect = _b[morekids]*scale;
summ effect;

* use intreg to get robust s.e.'s ;


gen hoursw1=hourswm;

replace hoursw1=. if hourswm==0;

intreg hoursw1 hourswm morekids agem1 agefstm boy1st boy2nd blackm hispm othracem, robust;




log close;

